==> nextcloud-30.0.13.tgz: nextcloud/apps/viewer/l10n/da.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Fremviser",
    "Simple file viewer with slideshow for media" : "Simpel filfremviser med slideshow til mediefiler",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vis dine seneste feriefotos og videoer som i en film, vis et glimt af din nyeste roman direkte fra din Nextcloud, vælg den bedste GIF fra din samling takket være den direkte fremvisning af dine favoritfiler og meget mere!",
    "Your browser does not support audio." : "Din browser understøtter ikke lyd.",
    "Error loading {name}" : "Fejl ved indlæsning af {name}",
    "Cancel" : "Annuller",
    "Image saved" : "Billede gemt",
    "Error saving image" : "Fejl ved lagring af billede",
    "Play the live photo" : "Afspil live foto",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Din browser understøtter ikke videoer.",
    "This file no longer exists" : "Denne fil eksisterer ikke længere",
    "There is no plugin available to display this file type" : "Der er intet plugin tilgængeligt til at vise denne filtype",
    "Edit" : "Rediger",
    "Exit full screen" : "Afslut fuldskærm",
    "Full screen" : "Fuld skærm",
    "Open sidebar" : "Åbn sidebjælke",
    "Download" : "Download",
    "Delete" : "Slet",
    "View" : "Vis",
    "Name" : "Navn",
    "Save" : "Gem",
    "Save as" : "Gem som",
    "Back" : "Tilbage",
    "Loading …" : "Indlæser …",
    "Reset" : "Nulstil",
    "All changes will be lost." : "Alle ændringer vil gå tabt.",
    "Are you sure you want to continue?" : "Er du sikker på, at du vil fortsætte?",
    "Apply" : "Anvend",
    "Warning" : "Advarsel",
    "Confirm" : "Bekræft",
    "Discard changes" : "Fortryd ændringer",
    "Undo" : "Fortryd",
    "Redo" : "Annuller fortryd",
    "Show original image" : "Vis originalt billede",
    "Zoom in" : "Zoom ind",
    "Zoom out" : "Zoom ud",
    "Toggle zoom menu" : "Slå zoom menu til/fra",
    "Adjust" : "Juster",
    "Fine-tune" : "Finjustering",
    "Filters" : "Filtre",
    "Watermark" : "Vandmærke",
    "Draw" : "Tegn",
    "Resize" : "Ændr størrelse",
    "Image name" : "Billednavn",
    "Invalid image." : "Ugyldigt billede.",
    "Error while uploading the image." : "Fejl under upload af billedet.",
    "are not images" : "er ikke billeder",
    "is not an image" : "er ikke et billede",
    "to be uploaded" : "skal uploades",
    "Crop" : "Beskæring",
    "Original" : "Original",
    "Custom" : "Brugerdefineret",
    "Square" : "Firkant",
    "Landscape" : "Landskab",
    "Portrait" : "Portræt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klasisk TV",
    "CinemaScope" : "BiografFormat",
    "Arrow" : "Pil",
    "Blur" : "Slør",
    "Brightness" : "Lysstyrke",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Flip ikke X",
    "Flip X" : "Flip X",
    "Un-flip Y" : "Flip ikke Y",
    "Flip Y" : "Flip Y",
    "HSV" : "HSV",
    "Hue" : "Nuance",
    "Saturation" : "Mætning",
    "Value" : "Værdi",
    "Image" : "Billede",
    "Importing …" : "Importerer ...",
    "+ Add image" : "+ Tilføj billede",
    "Upload image" : "Upload billede",
    "From gallery" : "Fra galleri",
    "Line" : "Linje",
    "Pen" : "Pen",
    "Polygon" : "Polygon",
    "Sides" : "Sider",
    "Rectangle" : "Rektangel",
    "Corner Radius" : "Hjørneradius",
    "Width in pixels" : "Bredde i pixels",
    "Height in pixels" : "Højde i pixels",
    "Toggle ratio lock" : "Slå forholdslås til/fra",
    "Reset to original image size" : "Nulstil til oprindelig billedstørrelse",
    "Rotate" : "Roter",
    "Text" : "Tekst",
    "Text spacing" : "Tekstafstand",
    "Text alignment" : "Tekstjustering",
    "Font family" : "Skrifttype familie",
    "Size" : "Størelse",
    "Letter spacing" : "Bogstavsafstand",
    "Line height" : "Linjehøjde",
    "Warmth" : "Varme",
    "+ Add watermark" : "+ Tilføj vandmærke",
    "+ Add text watermark" : "+ Tilføj tekstvandmærke",
    "Choose watermark type" : "Vælg vandmærketype",
    "Upload watermark" : "Upload vandmærke",
    "Add as text" : "Tilføj som tekst",
    "Padding" : "Padding",
    "Paddings" : "Paddings",
    "Shadow" : "Skygge",
    "Horizontal" : "Vandret",
    "Vertical" : "Lodret",
    "Opacity" : "Uigennemsigtighed",
    "Transparency" : "Gennemsigtighed",
    "Position" : "Placering",
    "Stroke" : "Slagtilfælde",
    "Save image as" : "Gem billede som",
    "Extension" : "Filtype",
    "Format" : "Format",
    "Name is required." : "Navn er krævet.",
    "Quality" : "Kvalitet",
    "Saved image size (width x height)" : "Gemt billedstørrelse (bredde x højde)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Bemærk, at det valgte beskæringsområde er lavere end den anvendte ændring, hvilket kan forårsage kvalitetsforringelse",
    "Actual size (100%)" : "Faktisk størrelse (100%)",
    "Fit size" : "Tilpasset størrelse",
    "Select image to add …" : "Vælg billede der skal tilføjes ...",
    "Failed to load image." : "Kunne ikke indlæse billede.",
    "Menu" : "Menu",
    "Width" : "Bredde",
    "Height" : "Højde",
    "No preview available for this crop item" : "Ingen forhåndsvisning tilgængelig for dette beskæringselement"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.12.tgz: nextcloud/apps/viewer/l10n/da.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Fremviser",
    "Simple file viewer with slideshow for media" : "Simpel filfremviser med slideshow til mediefiler",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vis dine seneste feriefotos og videoer som i en film, vis et glimt af din nyeste roman direkte fra din Nextcloud, vælg den bedste GIF fra din samling takket være den direkte fremvisning af dine favoritfiler og meget mere!",
    "Your browser does not support audio." : "Din browser understøtter ikke lyd.",
    "Error loading {name}" : "Fejl ved indlæsning af {name}",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "Du er ved at overskrive den originale fil. Er du sikker på at du ønsker at fortsætte?",
    "A file with this name already exists. Do you want to overwrite it?" : "En fil med dette navn eksisterer allerede. Ønsker du at overskrive den?",
    "Confirm overwrite" : "Bekræft overskrivning",
    "Cancel" : "Annuller",
    "Overwrite" : "Overskriv",
    "An error occurred while trying to confirm the file overwrite." : "En fejl opstod under forsøg på at bekræfte overskrivningen af filen.",
    "Image saved" : "Billede gemt",
    "Error saving image" : "Fejl ved lagring af billede",
    "Play the live photo" : "Afspil live foto",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Din browser understøtter ikke videoer.",
    "This file no longer exists" : "Denne fil eksisterer ikke længere",
    "There is no plugin available to display this file type" : "Der er intet plugin tilgængeligt til at vise denne filtype",
    "Edit" : "Redigér",
    "Exit full screen" : "Afslut fuldskærm",
    "Full screen" : "Fuld skærm",
    "Open sidebar" : "Åbn sidebjælke",
    "Download" : "Download",
    "Delete" : "Slet",
    "View" : "Vis",
    "Name" : "Navn",
    "Save" : "Gem",
    "Save as" : "Gem som",
    "Back" : "Tilbage",
    "Loading …" : "Indlæser …",
    "Reset" : "Nulstil",
    "All changes will be lost." : "Alle ændringer vil gå tabt.",
    "Are you sure you want to continue?" : "Er du sikker på, at du vil fortsætte?",
    "Apply" : "Anvend",
    "Warning" : "Advarsel",
    "Confirm" : "Bekræft",
    "Discard changes" : "Fortryd ændringer",
    "Undo" : "Fortryd",
    "Redo" : "Annuller fortryd",
    "Show original image" : "Vis originalt billede",
    "Zoom in" : "Zoom ind",
    "Zoom out" : "Zoom ud",
    "Toggle zoom menu" : "Slå zoom menu til/fra",
    "Adjust" : "Juster",
    "Fine-tune" : "Finjustering",
    "Filters" : "Filtre",
    "Watermark" : "Vandmærke",
    "Draw" : "Tegn",
    "Resize" : "Ændr størrelse",
    "Image name" : "Billednavn",
    "Invalid image." : "Ugyldigt billede.",
    "Error while uploading the image." : "Fejl under upload af billedet.",
    "are not images" : "er ikke billeder",
    "is not an image" : "er ikke et billede",
    "to be uploaded" : "skal uploades",
    "Crop" : "Beskæring",
    "Original" : "Original",
    "Custom" : "Brugerdefineret",
    "Square" : "Firkant",
    "Landscape" : "Landskab",
    "Portrait" : "Portræt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klasisk TV",
    "CinemaScope" : "BiografFormat",
    "Arrow" : "Pil",
    "Blur" : "Slør",
    "Brightness" : "Lysstyrke",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Flip ikke X",
    "Flip X" : "Flip X",
    "Un-flip Y" : "Flip ikke Y",
    "Flip Y" : "Flip Y",
    "HSV" : "HSV",
    "Hue" : "Nuance",
    "Saturation" : "Mætning",
    "Value" : "Værdi",
    "Image" : "Billede",
    "Importing …" : "Importerer ...",
    "+ Add image" : "+ Tilføj billede",
    "Upload image" : "Upload billede",
    "From gallery" : "Fra galleri",
    "Line" : "Linje",
    "Pen" : "Pen",
    "Polygon" : "Polygon",
    "Sides" : "Sider",
    "Rectangle" : "Rektangel",
    "Corner Radius" : "Hjørneradius",
    "Width in pixels" : "Bredde i pixels",
    "Height in pixels" : "Højde i pixels",
    "Toggle ratio lock" : "Slå forholdslås til/fra",
    "Reset to original image size" : "Nulstil til oprindelig billedstørrelse",
    "Rotate" : "Roter",
    "Text" : "Tekst",
    "Text spacing" : "Tekstafstand",
    "Text alignment" : "Tekstjustering",
    "Font family" : "Skrifttype familie",
    "Size" : "Størelse",
    "Letter spacing" : "Bogstavsafstand",
    "Line height" : "Linjehøjde",
    "Warmth" : "Varme",
    "+ Add watermark" : "+ Tilføj vandmærke",
    "+ Add text watermark" : "+ Tilføj tekstvandmærke",
    "Choose watermark type" : "Vælg vandmærketype",
    "Upload watermark" : "Upload vandmærke",
    "Add as text" : "Tilføj som tekst",
    "Padding" : "Padding",
    "Paddings" : "Paddings",
    "Shadow" : "Skygge",
    "Horizontal" : "Vandret",
    "Vertical" : "Lodret",
    "Opacity" : "Uigennemsigtighed",
    "Transparency" : "Gennemsigtighed",
    "Position" : "Placering",
    "Stroke" : "Slagtilfælde",
    "Save image as" : "Gem billede som",
    "Extension" : "Filtype",
    "Format" : "Format",
    "Name is required." : "Navn er krævet.",
    "Quality" : "Kvalitet",
    "Saved image size (width x height)" : "Gemt billedstørrelse (bredde x højde)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Bemærk, at det valgte beskæringsområde er lavere end den anvendte ændring, hvilket kan forårsage kvalitetsforringelse",
    "Actual size (100%)" : "Faktisk størrelse (100%)",
    "Fit size" : "Tilpasset størrelse",
    "Select image to add …" : "Vælg billede der skal tilføjes ...",
    "Failed to load image." : "Kunne ikke indlæse billede.",
    "Menu" : "Menu",
    "Width" : "Bredde",
    "Height" : "Højde",
    "No preview available for this crop item" : "Ingen forhåndsvisning tilgængelig for dette beskæringselement"
},
"nplurals=2; plural=(n != 1);");
